@@ -14,6 +14,7 @@ function (col = "blue", alpha = 0.5, lty = 1, ...)
     xy <- data.frame(xy)
     xy <- rbind(xy, xy[1, ])
     polygon(xy$x, xy$y, lty = lty, col = col, ...)
-    xy
+    
+    invisible(xy)
 }
 
